@@ -602,7 +602,7 @@ impl<'a, I: Tokens> Parser<I> {
                     expect!(p, ',');
                     // Handle trailing comma.
                     if is!(p, ')') {
-                        if is_dynamic_import {
+                        if is_dynamic_import && !p.input.syntax().import_assertions() {
                             syntax_error!(
                                 p,
                                 span!(p, start),
